@@ -31,7 +31,6 @@
 
 OctaveBackend::OctaveBackend(QObject* parent, const QList< QVariant > args): Backend(parent, args)
 {
-    qDebug();
     new OctaveHistoryExtension(this);
     new OctaveScriptExtension(this);
     new OctavePlotExtension(this);
@@ -46,6 +45,11 @@ QString OctaveBackend::id() const
     return QLatin1String("octave");
 }
 
+QString OctaveBackend::version() const
+{
+    return QLatin1String("4.0 and 4.2");
+}
+
 Cantor::Backend::Capabilities OctaveBackend::capabilities() const
 {
     return SyntaxHighlighting | Completion | SyntaxHelp | VariableManagement;
@@ -53,7 +57,6 @@ Cantor::Backend::Capabilities OctaveBackend::capabilities() const
 
 Cantor::Session* OctaveBackend::createSession()
 {
-    qDebug();
     return new OctaveSession(this);
 }
 
