@@ -33,7 +33,9 @@ static const char* printCommand = "cantor_print();";
 OctaveExpression::OctaveExpression(Cantor::Session* session): Expression(session),
     m_plotPending(false),
     m_finished(false),
-    m_error(false)
+    m_error(false),
+    m_appendPlotCommand(false),
+    m_appendDot(false)
 {
     m_plotCommands << QLatin1String("plot") << QLatin1String("semilogx") << QLatin1String("semilogy") << QLatin1String("loglog")
                    << QLatin1String("polar") << QLatin1String("contour") << QLatin1String("bar")
@@ -42,6 +44,7 @@ OctaveExpression::OctaveExpression(Cantor::Session* session): Expression(session
                    << QLatin1String("stem") << QLatin1String("stem3") << QLatin1String("scatter") << QLatin1String("pareto") << QLatin1String("rose")
                    << QLatin1String("pie") << QLatin1String("quiver") << QLatin1String("compass") << QLatin1String("feather")
                    << QLatin1String("pcolor") << QLatin1String("area") << QLatin1String("fill") << QLatin1String("comet")
+                   << QLatin1String("plotmatrix")
                    /* 3d-plots */
                    << QLatin1String("plot3")
                    << QLatin1String("mesh") << QLatin1String("meshc") << QLatin1String("meshz")
@@ -81,9 +84,11 @@ void OctaveExpression::evaluate()
         if (!cmd.endsWith(QLatin1Char(';')) && !cmd.endsWith(QLatin1Char(',')))
         {
             cmd += QLatin1Char(',');
+            m_appendDot = true;
         }
         cmd += QLatin1String(printCommand);
         setCommand(cmd);
+        m_appendPlotCommand = true;
     }
     m_finished = false;
     setStatus(Computing);
@@ -140,6 +145,20 @@ void OctaveExpression::parsePlotFile(QString file)
 void OctaveExpression::finalize()
 {
     qDebug() << "finalize: " << m_resultString;
+
+    if (m_appendPlotCommand)
+    {
+        QString cmd = command();
+        cmd.remove(cmd.length()-strlen(printCommand),strlen(printCommand));
+        m_appendPlotCommand = false;
+        if (m_appendDot)
+            {
+            cmd.remove(cmd.length()-1,1);
+            m_appendDot = false;
+            }
+        setCommand(cmd);
+    }
+
     foreach ( const QString& line, m_resultString.simplified().split(QLatin1Char('\n'), QString::SkipEmptyParts) )
     {
         if ((m_resultString.contains(QLatin1Char('='))) && !(command().startsWith(QLatin1String("help(")))
