@@ -64,18 +64,18 @@ public:
     QalculateSession( Cantor::Backend* backend);
     ~QalculateSession();
 
-    virtual void login();
-    virtual void logout();
+    virtual void login() override;
+    virtual void logout() override;
 
-    virtual void interrupt();
+    virtual void interrupt() override;
 
-    virtual Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave);
-    virtual Cantor::CompletionObject* completionFor(const QString& cmd, int index=-1);
-    virtual Cantor::SyntaxHelpObject* syntaxHelpFor(const QString& cmd);
-    virtual QSyntaxHighlighter* syntaxHighlighter(QObject* parent);
+    virtual Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave) override;
+    virtual Cantor::CompletionObject* completionFor(const QString& cmd, int index=-1) override;
+    virtual Cantor::SyntaxHelpObject* syntaxHelpFor(const QString& cmd) override;
+    virtual QSyntaxHighlighter* syntaxHighlighter(QObject* parent) override;
 
     void runExpression();
-    QAbstractItemModel* variableModel();
+    QAbstractItemModel* variableModel() override;
 
 public:
     QMap<QString,QString> variables;
