@@ -42,7 +42,7 @@ PanelPluginHandler::PanelPluginHandler( QObject* parent ) : QObject(parent) ,
                                                             d(new PanelPluginHandlerPrivate)
 {
     setObjectName(QLatin1String("PanelPluginHandler"));
-    d->session=0;
+    d->session=nullptr;
 }
 
 PanelPluginHandler::~PanelPluginHandler()
@@ -52,7 +52,7 @@ PanelPluginHandler::~PanelPluginHandler()
 
 void PanelPluginHandler::loadPlugins()
 {
-    if(d->session==0)
+    if(d->session==nullptr)
         return;
     qDebug()<<"loading panel plugins for session of type "<<d->session->backend()->name();
 
@@ -71,6 +71,9 @@ void PanelPluginHandler::loadPlugins()
         panels = panelDir.entryList();
 
         foreach (const QString &panel, panels){
+            if (panel==QLatin1String(".") || panel==QLatin1String(".."))
+                continue;
+
             loader.setFileName(dir + QDir::separator() + panel);
 
             if (!loader.load()){
